
/* Generated data (by glib-mkenums) */

#include "e-util-enumtypes.h"
/* enumerations from "/usr/src/ports/evolution/evolution-3.18.5.2-1.x86_64/src/evolution-3.18.5.2/e-util/e-util-enums.h" */
#include "/usr/src/ports/evolution/evolution-3.18.5.2-1.x86_64/src/evolution-3.18.5.2/e-util/e-util-enums.h"

GType
e_activity_state_get_type (void)
{
	static volatile gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_ACTIVITY_RUNNING,
			  "E_ACTIVITY_RUNNING",
			  "running" },
			{ E_ACTIVITY_WAITING,
			  "E_ACTIVITY_WAITING",
			  "waiting" },
			{ E_ACTIVITY_CANCELLED,
			  "E_ACTIVITY_CANCELLED",
			  "cancelled" },
			{ E_ACTIVITY_COMPLETED,
			  "E_ACTIVITY_COMPLETED",
			  "completed" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EActivityState"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}

GType
e_automatic_action_policy_get_type (void)
{
	static volatile gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_AUTOMATIC_ACTION_POLICY_ASK,
			  "E_AUTOMATIC_ACTION_POLICY_ASK",
			  "ask" },
			{ E_AUTOMATIC_ACTION_POLICY_ALWAYS,
			  "E_AUTOMATIC_ACTION_POLICY_ALWAYS",
			  "always" },
			{ E_AUTOMATIC_ACTION_POLICY_NEVER,
			  "E_AUTOMATIC_ACTION_POLICY_NEVER",
			  "never" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EAutomaticActionPolicy"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}

GType
e_date_weekday_get_type (void)
{
	static volatile gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_DATE_BAD_WEEKDAY,
			  "E_DATE_BAD_WEEKDAY",
			  "bad-weekday" },
			{ E_DATE_MONDAY,
			  "E_DATE_MONDAY",
			  "monday" },
			{ E_DATE_TUESDAY,
			  "E_DATE_TUESDAY",
			  "tuesday" },
			{ E_DATE_WEDNESDAY,
			  "E_DATE_WEDNESDAY",
			  "wednesday" },
			{ E_DATE_THURSDAY,
			  "E_DATE_THURSDAY",
			  "thursday" },
			{ E_DATE_FRIDAY,
			  "E_DATE_FRIDAY",
			  "friday" },
			{ E_DATE_SATURDAY,
			  "E_DATE_SATURDAY",
			  "saturday" },
			{ E_DATE_SUNDAY,
			  "E_DATE_SUNDAY",
			  "sunday" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EDateWeekday"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}

GType
e_duration_type_get_type (void)
{
	static volatile gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_DURATION_MINUTES,
			  "E_DURATION_MINUTES",
			  "minutes" },
			{ E_DURATION_HOURS,
			  "E_DURATION_HOURS",
			  "hours" },
			{ E_DURATION_DAYS,
			  "E_DURATION_DAYS",
			  "days" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EDurationType"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}

GType
e_html_editor_selection_block_format_get_type (void)
{
	static volatile gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_NONE,
			  "E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_NONE",
			  "none" },
			{ E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_PARAGRAPH,
			  "E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_PARAGRAPH",
			  "paragraph" },
			{ E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_PRE,
			  "E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_PRE",
			  "pre" },
			{ E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_ADDRESS,
			  "E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_ADDRESS",
			  "address" },
			{ E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_BLOCKQUOTE,
			  "E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_BLOCKQUOTE",
			  "blockquote" },
			{ E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_H1,
			  "E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_H1",
			  "h1" },
			{ E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_H2,
			  "E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_H2",
			  "h2" },
			{ E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_H3,
			  "E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_H3",
			  "h3" },
			{ E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_H4,
			  "E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_H4",
			  "h4" },
			{ E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_H5,
			  "E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_H5",
			  "h5" },
			{ E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_H6,
			  "E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_H6",
			  "h6" },
			{ E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_UNORDERED_LIST,
			  "E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_UNORDERED_LIST",
			  "unordered-list" },
			{ E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_ORDERED_LIST,
			  "E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_ORDERED_LIST",
			  "ordered-list" },
			{ E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_ORDERED_LIST_ROMAN,
			  "E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_ORDERED_LIST_ROMAN",
			  "ordered-list-roman" },
			{ E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_ORDERED_LIST_ALPHA,
			  "E_HTML_EDITOR_SELECTION_BLOCK_FORMAT_ORDERED_LIST_ALPHA",
			  "ordered-list-alpha" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EHTMLEditorSelectionBlockFormat"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}

GType
e_html_editor_selection_font_size_get_type (void)
{
	static volatile gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_HTML_EDITOR_SELECTION_FONT_SIZE_TINY,
			  "E_HTML_EDITOR_SELECTION_FONT_SIZE_TINY",
			  "tiny" },
			{ E_HTML_EDITOR_SELECTION_FONT_SIZE_SMALL,
			  "E_HTML_EDITOR_SELECTION_FONT_SIZE_SMALL",
			  "small" },
			{ E_HTML_EDITOR_SELECTION_FONT_SIZE_NORMAL,
			  "E_HTML_EDITOR_SELECTION_FONT_SIZE_NORMAL",
			  "normal" },
			{ E_HTML_EDITOR_SELECTION_FONT_SIZE_BIG,
			  "E_HTML_EDITOR_SELECTION_FONT_SIZE_BIG",
			  "big" },
			{ E_HTML_EDITOR_SELECTION_FONT_SIZE_BIGGER,
			  "E_HTML_EDITOR_SELECTION_FONT_SIZE_BIGGER",
			  "bigger" },
			{ E_HTML_EDITOR_SELECTION_FONT_SIZE_LARGE,
			  "E_HTML_EDITOR_SELECTION_FONT_SIZE_LARGE",
			  "large" },
			{ E_HTML_EDITOR_SELECTION_FONT_SIZE_VERY_LARGE,
			  "E_HTML_EDITOR_SELECTION_FONT_SIZE_VERY_LARGE",
			  "very-large" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EHTMLEditorSelectionFontSize"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}

GType
e_html_editor_selection_alignment_get_type (void)
{
	static volatile gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_HTML_EDITOR_SELECTION_ALIGNMENT_LEFT,
			  "E_HTML_EDITOR_SELECTION_ALIGNMENT_LEFT",
			  "left" },
			{ E_HTML_EDITOR_SELECTION_ALIGNMENT_CENTER,
			  "E_HTML_EDITOR_SELECTION_ALIGNMENT_CENTER",
			  "center" },
			{ E_HTML_EDITOR_SELECTION_ALIGNMENT_RIGHT,
			  "E_HTML_EDITOR_SELECTION_ALIGNMENT_RIGHT",
			  "right" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EHTMLEditorSelectionAlignment"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}

GType
e_html_editor_selection_granularity_get_type (void)
{
	static volatile gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_HTML_EDITOR_SELECTION_GRANULARITY_CHARACTER,
			  "E_HTML_EDITOR_SELECTION_GRANULARITY_CHARACTER",
			  "character" },
			{ E_HTML_EDITOR_SELECTION_GRANULARITY_WORD,
			  "E_HTML_EDITOR_SELECTION_GRANULARITY_WORD",
			  "word" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EHTMLEditorSelectionGranularity"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}

GType
e_html_editor_view_command_get_type (void)
{
	static volatile gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_HTML_EDITOR_VIEW_COMMAND_BACKGROUND_COLOR,
			  "E_HTML_EDITOR_VIEW_COMMAND_BACKGROUND_COLOR",
			  "background-color" },
			{ E_HTML_EDITOR_VIEW_COMMAND_BOLD,
			  "E_HTML_EDITOR_VIEW_COMMAND_BOLD",
			  "bold" },
			{ E_HTML_EDITOR_VIEW_COMMAND_COPY,
			  "E_HTML_EDITOR_VIEW_COMMAND_COPY",
			  "copy" },
			{ E_HTML_EDITOR_VIEW_COMMAND_CREATE_LINK,
			  "E_HTML_EDITOR_VIEW_COMMAND_CREATE_LINK",
			  "create-link" },
			{ E_HTML_EDITOR_VIEW_COMMAND_CUT,
			  "E_HTML_EDITOR_VIEW_COMMAND_CUT",
			  "cut" },
			{ E_HTML_EDITOR_VIEW_COMMAND_DEFAULT_PARAGRAPH_SEPARATOR,
			  "E_HTML_EDITOR_VIEW_COMMAND_DEFAULT_PARAGRAPH_SEPARATOR",
			  "default-paragraph-separator" },
			{ E_HTML_EDITOR_VIEW_COMMAND_DELETE,
			  "E_HTML_EDITOR_VIEW_COMMAND_DELETE",
			  "delete" },
			{ E_HTML_EDITOR_VIEW_COMMAND_FIND_STRING,
			  "E_HTML_EDITOR_VIEW_COMMAND_FIND_STRING",
			  "find-string" },
			{ E_HTML_EDITOR_VIEW_COMMAND_FONT_NAME,
			  "E_HTML_EDITOR_VIEW_COMMAND_FONT_NAME",
			  "font-name" },
			{ E_HTML_EDITOR_VIEW_COMMAND_FONT_SIZE,
			  "E_HTML_EDITOR_VIEW_COMMAND_FONT_SIZE",
			  "font-size" },
			{ E_HTML_EDITOR_VIEW_COMMAND_FONT_SIZE_DELTA,
			  "E_HTML_EDITOR_VIEW_COMMAND_FONT_SIZE_DELTA",
			  "font-size-delta" },
			{ E_HTML_EDITOR_VIEW_COMMAND_FORE_COLOR,
			  "E_HTML_EDITOR_VIEW_COMMAND_FORE_COLOR",
			  "fore-color" },
			{ E_HTML_EDITOR_VIEW_COMMAND_FORMAT_BLOCK,
			  "E_HTML_EDITOR_VIEW_COMMAND_FORMAT_BLOCK",
			  "format-block" },
			{ E_HTML_EDITOR_VIEW_COMMAND_FORWARD_DELETE,
			  "E_HTML_EDITOR_VIEW_COMMAND_FORWARD_DELETE",
			  "forward-delete" },
			{ E_HTML_EDITOR_VIEW_COMMAND_HILITE_COLOR,
			  "E_HTML_EDITOR_VIEW_COMMAND_HILITE_COLOR",
			  "hilite-color" },
			{ E_HTML_EDITOR_VIEW_COMMAND_INDENT,
			  "E_HTML_EDITOR_VIEW_COMMAND_INDENT",
			  "indent" },
			{ E_HTML_EDITOR_VIEW_COMMAND_INSERT_HTML,
			  "E_HTML_EDITOR_VIEW_COMMAND_INSERT_HTML",
			  "insert-html" },
			{ E_HTML_EDITOR_VIEW_COMMAND_INSERT_HORIZONTAL_RULE,
			  "E_HTML_EDITOR_VIEW_COMMAND_INSERT_HORIZONTAL_RULE",
			  "insert-horizontal-rule" },
			{ E_HTML_EDITOR_VIEW_COMMAND_INSERT_IMAGE,
			  "E_HTML_EDITOR_VIEW_COMMAND_INSERT_IMAGE",
			  "insert-image" },
			{ E_HTML_EDITOR_VIEW_COMMAND_INSERT_LINE_BREAK,
			  "E_HTML_EDITOR_VIEW_COMMAND_INSERT_LINE_BREAK",
			  "insert-line-break" },
			{ E_HTML_EDITOR_VIEW_COMMAND_INSERT_NEW_LINE_IN_QUOTED_CONTENT,
			  "E_HTML_EDITOR_VIEW_COMMAND_INSERT_NEW_LINE_IN_QUOTED_CONTENT",
			  "insert-new-line-in-quoted-content" },
			{ E_HTML_EDITOR_VIEW_COMMAND_INSERT_ORDERED_LIST,
			  "E_HTML_EDITOR_VIEW_COMMAND_INSERT_ORDERED_LIST",
			  "insert-ordered-list" },
			{ E_HTML_EDITOR_VIEW_COMMAND_INSERT_PARAGRAPH,
			  "E_HTML_EDITOR_VIEW_COMMAND_INSERT_PARAGRAPH",
			  "insert-paragraph" },
			{ E_HTML_EDITOR_VIEW_COMMAND_INSERT_TEXT,
			  "E_HTML_EDITOR_VIEW_COMMAND_INSERT_TEXT",
			  "insert-text" },
			{ E_HTML_EDITOR_VIEW_COMMAND_INSERT_UNORDERED_LIST,
			  "E_HTML_EDITOR_VIEW_COMMAND_INSERT_UNORDERED_LIST",
			  "insert-unordered-list" },
			{ E_HTML_EDITOR_VIEW_COMMAND_ITALIC,
			  "E_HTML_EDITOR_VIEW_COMMAND_ITALIC",
			  "italic" },
			{ E_HTML_EDITOR_VIEW_COMMAND_JUSTIFY_CENTER,
			  "E_HTML_EDITOR_VIEW_COMMAND_JUSTIFY_CENTER",
			  "justify-center" },
			{ E_HTML_EDITOR_VIEW_COMMAND_JUSTIFY_FULL,
			  "E_HTML_EDITOR_VIEW_COMMAND_JUSTIFY_FULL",
			  "justify-full" },
			{ E_HTML_EDITOR_VIEW_COMMAND_JUSTIFY_LEFT,
			  "E_HTML_EDITOR_VIEW_COMMAND_JUSTIFY_LEFT",
			  "justify-left" },
			{ E_HTML_EDITOR_VIEW_COMMAND_JUSTIFY_NONE,
			  "E_HTML_EDITOR_VIEW_COMMAND_JUSTIFY_NONE",
			  "justify-none" },
			{ E_HTML_EDITOR_VIEW_COMMAND_JUSTIFY_RIGHT,
			  "E_HTML_EDITOR_VIEW_COMMAND_JUSTIFY_RIGHT",
			  "justify-right" },
			{ E_HTML_EDITOR_VIEW_COMMAND_OUTDENT,
			  "E_HTML_EDITOR_VIEW_COMMAND_OUTDENT",
			  "outdent" },
			{ E_HTML_EDITOR_VIEW_COMMAND_PASTE,
			  "E_HTML_EDITOR_VIEW_COMMAND_PASTE",
			  "paste" },
			{ E_HTML_EDITOR_VIEW_COMMAND_PASTE_AND_MATCH_STYLE,
			  "E_HTML_EDITOR_VIEW_COMMAND_PASTE_AND_MATCH_STYLE",
			  "paste-and-match-style" },
			{ E_HTML_EDITOR_VIEW_COMMAND_PASTE_AS_PLAIN_TEXT,
			  "E_HTML_EDITOR_VIEW_COMMAND_PASTE_AS_PLAIN_TEXT",
			  "paste-as-plain-text" },
			{ E_HTML_EDITOR_VIEW_COMMAND_PRINT,
			  "E_HTML_EDITOR_VIEW_COMMAND_PRINT",
			  "print" },
			{ E_HTML_EDITOR_VIEW_COMMAND_REDO,
			  "E_HTML_EDITOR_VIEW_COMMAND_REDO",
			  "redo" },
			{ E_HTML_EDITOR_VIEW_COMMAND_REMOVE_FORMAT,
			  "E_HTML_EDITOR_VIEW_COMMAND_REMOVE_FORMAT",
			  "remove-format" },
			{ E_HTML_EDITOR_VIEW_COMMAND_SELECT_ALL,
			  "E_HTML_EDITOR_VIEW_COMMAND_SELECT_ALL",
			  "select-all" },
			{ E_HTML_EDITOR_VIEW_COMMAND_STRIKETHROUGH,
			  "E_HTML_EDITOR_VIEW_COMMAND_STRIKETHROUGH",
			  "strikethrough" },
			{ E_HTML_EDITOR_VIEW_COMMAND_STYLE_WITH_CSS,
			  "E_HTML_EDITOR_VIEW_COMMAND_STYLE_WITH_CSS",
			  "style-with-css" },
			{ E_HTML_EDITOR_VIEW_COMMAND_SUBSCRIPT,
			  "E_HTML_EDITOR_VIEW_COMMAND_SUBSCRIPT",
			  "subscript" },
			{ E_HTML_EDITOR_VIEW_COMMAND_SUPERSCRIPT,
			  "E_HTML_EDITOR_VIEW_COMMAND_SUPERSCRIPT",
			  "superscript" },
			{ E_HTML_EDITOR_VIEW_COMMAND_TRANSPOSE,
			  "E_HTML_EDITOR_VIEW_COMMAND_TRANSPOSE",
			  "transpose" },
			{ E_HTML_EDITOR_VIEW_COMMAND_UNDERLINE,
			  "E_HTML_EDITOR_VIEW_COMMAND_UNDERLINE",
			  "underline" },
			{ E_HTML_EDITOR_VIEW_COMMAND_UNDO,
			  "E_HTML_EDITOR_VIEW_COMMAND_UNDO",
			  "undo" },
			{ E_HTML_EDITOR_VIEW_COMMAND_UNLINK,
			  "E_HTML_EDITOR_VIEW_COMMAND_UNLINK",
			  "unlink" },
			{ E_HTML_EDITOR_VIEW_COMMAND_UNSELECT,
			  "E_HTML_EDITOR_VIEW_COMMAND_UNSELECT",
			  "unselect" },
			{ E_HTML_EDITOR_VIEW_COMMAND_USE_CSS,
			  "E_HTML_EDITOR_VIEW_COMMAND_USE_CSS",
			  "use-css" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EHTMLEditorViewCommand"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}

GType
e_image_loading_policy_get_type (void)
{
	static volatile gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_IMAGE_LOADING_POLICY_NEVER,
			  "E_IMAGE_LOADING_POLICY_NEVER",
			  "never" },
			{ E_IMAGE_LOADING_POLICY_SOMETIMES,
			  "E_IMAGE_LOADING_POLICY_SOMETIMES",
			  "sometimes" },
			{ E_IMAGE_LOADING_POLICY_ALWAYS,
			  "E_IMAGE_LOADING_POLICY_ALWAYS",
			  "always" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EImageLoadingPolicy"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}


/* Generated data ends here */

